@@ -1,7 +1,22 @@
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2010-01-31"
-__copyright__ = "Copyright (C) 2010 Anders Logg"
-__license__  = "GNU LGPL version 3 or any later version"
+# Copyright (C) 2010 Anders Logg
+#
+# This file is part of FIAT.
+#
+# FIAT is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FIAT is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FIAT. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2010-01-31
+# Last changed: 2010-01-31
 
 import sys, pickle
 from FIAT import supported_elements, make_quadrature, ufc_simplex
